@@ -21,7 +21,7 @@
 
 import sys
 import enum
-import os.path
+import os
 import io
 import logging
 import functools
@@ -39,7 +39,7 @@ import yaml
 
 import qutebrowser
 import qutebrowser.utils  # for test_qualname
-from qutebrowser.utils import utils, version, usertypes
+from qutebrowser.utils import utils, usertypes
 from qutebrowser.utils.utils import VersionNumber
 
 
@@ -57,6 +57,7 @@ class TestVersionNumber:
         (VersionNumber(5, 15, 2), '5.15.2'),
         (VersionNumber(5, 15), '5.15'),
         (VersionNumber(5), '5'),
+        (VersionNumber(1, 2, 3, 4), '1.2.3.4'),
     ])
     def test_str(self, num, expected):
         assert str(num) == expected
@@ -69,6 +70,7 @@ class TestVersionNumber:
         (VersionNumber(5, 15, 2), VersionNumber(5, 15)),
         (VersionNumber(5, 15), VersionNumber(5, 15)),
         (VersionNumber(6), VersionNumber(6)),
+        (VersionNumber(1, 2, 3, 4), VersionNumber(1, 2)),
     ])
     def test_strip_patch(self, num, expected):
         assert num.strip_patch() == expected
@@ -79,6 +81,7 @@ class TestVersionNumber:
         ('5.15', VersionNumber(5, 15)),
         ('5.15.3', VersionNumber(5, 15, 3)),
         ('5.15.3.dev1234', VersionNumber(5, 15, 3)),
+        ('1.2.3.4', VersionNumber(1, 2, 3, 4)),
     ])
     def test_parse_valid(self, s, expected):
         assert VersionNumber.parse(s) == expected
@@ -217,16 +220,6 @@ class TestElidingFilenames:
         assert utils.elide_filename(filename, length) == expected
 
 
-@pytest.fixture(params=[True, False])
-def freezer(request, monkeypatch):
-    if request.param and not getattr(sys, 'frozen', False):
-        monkeypatch.setattr(sys, 'frozen', True, raising=False)
-        monkeypatch.setattr(sys, 'executable', qutebrowser.__file__)
-    elif not request.param and getattr(sys, 'frozen', False):
-        # Want to test unfrozen tests, but we are frozen
-        pytest.skip("Can't run with sys.frozen = True!")
-
-
 @pytest.mark.parametrize('seconds, out', [
     (-1, '-0:01'),
     (0, '0:00'),
@@ -553,6 +546,34 @@ class TestIsEnum:
         assert not utils.is_enum(23)
 
 
+class SomeEnum(enum.Enum):
+
+    some_value = enum.auto()
+
+
+class TestPyEnumStr:
+
+    @pytest.fixture
+    def val(self):
+        return SomeEnum.some_value
+
+    def test_fake_old_python_version(self, monkeypatch, val):
+        monkeypatch.setattr(sys, 'version_info', (3, 9, 2))
+        assert utils.pyenum_str(val) == str(val)
+
+    def test_fake_new_python_version(self, monkeypatch, val):
+        monkeypatch.setattr(sys, 'version_info', (3, 10, 0))
+        assert utils.pyenum_str(val) == repr(val)
+
+    def test_real_result(self, val):
+        assert utils.pyenum_str(val) == 'SomeEnum.some_value'
+
+    @pytest.mark.skipif(sys.version_info[:2] < (3, 10), reason='Needs Python 3.10+')
+    def test_needed(self, val):
+        """Fail if this change gets revered before the final 3.10 release."""
+        assert str(val) != 'SomeEnum.some_value'
+
+
 class TestRaises:
 
     """Test raises."""
@@ -725,6 +746,7 @@ class TestGetSetClipboard:
 class TestOpenFile:
 
     @pytest.mark.not_frozen
+    @pytest.mark.not_flatpak
     def test_cmdline_without_argument(self, caplog, config_stub):
         executable = shlex.quote(sys.executable)
         cmdline = '{} -c pass'.format(executable)
@@ -734,6 +756,7 @@ class TestOpenFile:
             r'Opening /foo/bar with \[.*python.*/foo/bar.*\]', result)
 
     @pytest.mark.not_frozen
+    @pytest.mark.not_flatpak
     def test_cmdline_with_argument(self, caplog, config_stub):
         executable = shlex.quote(sys.executable)
         cmdline = '{} -c pass {{}} raboof'.format(executable)
@@ -743,6 +766,7 @@ class TestOpenFile:
             r"Opening /foo/bar with \[.*python.*/foo/bar.*'raboof'\]", result)
 
     @pytest.mark.not_frozen
+    @pytest.mark.not_flatpak
     def test_setting_override(self, caplog, config_stub):
         executable = shlex.quote(sys.executable)
         cmdline = '{} -c pass'.format(executable)
@@ -765,17 +789,7 @@ class TestOpenFile:
             r"Opening /foo/bar with the system application", result)
         openurl_mock.assert_called_with(QUrl('file:///foo/bar'))
 
-    @pytest.fixture
-    def sandbox_patch(self, monkeypatch):
-        info = version.DistributionInfo(
-            id='org.kde.Platform',
-            parsed=version.Distribution.kde_flatpak,
-            version=VersionNumber.parse('5.12'),
-            pretty='Unknown')
-        monkeypatch.setattr(version, 'distribution',
-                            lambda: info)
-
-    def test_cmdline_sandboxed(self, sandbox_patch,
+    def test_cmdline_sandboxed(self, fake_flatpak,
                                config_stub, message_mock, caplog):
         with caplog.at_level(logging.ERROR):
             utils.open_file('/foo/bar', 'custom_cmd')
@@ -783,7 +797,7 @@ class TestOpenFile:
         assert msg.text == 'Cannot spawn download dispatcher from sandbox'
 
     @pytest.mark.not_frozen
-    def test_setting_override_sandboxed(self, sandbox_patch, openurl_mock,
+    def test_setting_override_sandboxed(self, fake_flatpak, openurl_mock,
                                         caplog, config_stub):
         config_stub.val.downloads.open_dispatcher = 'test'
 
@@ -795,7 +809,7 @@ class TestOpenFile:
         openurl_mock.assert_called_with(QUrl('file:///foo/bar'))
 
     def test_system_default_sandboxed(self, config_stub, openurl_mock,
-                                      sandbox_patch):
+                                      fake_flatpak):
         utils.open_file('/foo/bar')
         openurl_mock.assert_called_with(QUrl('file:///foo/bar'))
 
@@ -826,20 +840,19 @@ class TestYaml:
         with pytest.raises(yaml.YAMLError):
             utils.yaml_load("._")
 
-    def test_load_file(self, tmpdir):
-        tmpfile = tmpdir / 'foo.yml'
-        tmpfile.write('[1, 2]')
+    def test_load_file(self, tmp_path):
+        tmpfile = tmp_path / 'foo.yml'
+        tmpfile.write_text('[1, 2]')
         with tmpfile.open(encoding='utf-8') as f:
             assert utils.yaml_load(f) == [1, 2]
 
     def test_dump(self):
         assert utils.yaml_dump([1, 2]) == '- 1\n- 2\n'
 
-    def test_dump_file(self, tmpdir):
-        tmpfile = tmpdir / 'foo.yml'
-        with tmpfile.open('w', encoding='utf-8') as f:
-            utils.yaml_dump([1, 2], f)
-        assert tmpfile.read() == '- 1\n- 2\n'
+    def test_dump_file(self, tmp_path):
+        tmpfile = tmp_path / 'foo.yml'
+        tmpfile.write_text(utils.yaml_dump([1, 2]), encoding='utf-8')
+        assert tmpfile.read_text() == '- 1\n- 2\n'
 
 
 @pytest.mark.parametrize('elems, n, expected', [
@@ -892,13 +905,6 @@ def test_ceil_log_invalid(number, base):
         utils.ceil_log(number, base)
 
 
-@pytest.mark.parametrize('skip', [True, False])
-def test_libgl_workaround(monkeypatch, skip):
-    if skip:
-        monkeypatch.setenv('QUTE_SKIP_LIBGL_WORKAROUND', '1')
-    utils.libgl_workaround()  # Just make sure it doesn't crash.
-
-
 @pytest.mark.parametrize('duration, out', [
     ("0", 0),
     ("0s", 0),
